Documentation
¶
Overview ¶
Package is contains helpers for working with integers that might be even or odd.
This extensive work involved in the creation of this package was inspired by https://www.npmjs.com/package/is-even.
Get even with the modulo operator.
Index ¶
Examples ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func True ¶
True accurately reports if b is, in fact, true.
Example ¶
package main
import (
"fmt"
"blake.io/is"
)
func main() {
var theZeroValueOfBool bool
if is.True(!theZeroValueOfBool) {
fmt.Println("theZeroValueOfBool is, in fact, the zero value of bool")
}
if is.False(theZeroValueOfBool) {
fmt.Println("theZeroValueOfBool is the opposite of not the zero value of bool")
}
}
Output: theZeroValueOfBool is, in fact, the zero value of bool theZeroValueOfBool is the opposite of not the zero value of bool
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.